//
// APIService.swift
// VRPaymeTestApp
// 
// Created by VR Payment GmbH on 24.09.19
// Copyright © 2019 VR Payment GmbH. All rights reserved.
//

import Foundation

/// Protocol for the APIService so that we can change the implementation between Swift and ObjC
@objc protocol APIService {

    /// Starts a new payment using the VRPayme framework
    ///
    /// - Parameters:
    ///   - amount: Payment amount, including tip and tax
    ///   - tax: Payment tax
    ///   - cashier: Payment cashier
    ///   - tip: Payment tip, only for reference, the amount should include the tip
    ///   - email: The email where the payment receipt will be sent
    ///   - userReference: The reference given by the user for the transaction
    /// - Throws: An error of type ‘RequestBuilderError’
    func performPayment(amount: Int,
                        tax: NSNumber?,
                        cashier: String?,
                        tip: Int,
                        email: String?,
                        userReference: String?) throws

    /// Starts a payment cancellation using the VRPayme framework
    ///
    /// - Parameters:
    ///   - identifier: The identifier given to the transaction by the terminal
    ///   - amount: Payment amount, including tip and tax
    /// - Throws: An error of type ‘RequestBuilderError’
    func performCancelation(identifier: String, amount: Int) throws

    /// Starts a new data clearing using the VRPayme framework
    ///
    /// - Throws: An error of type 'RequestBuildError'
    func performDataClearing() throws

    /// Starts a new sync of pending transactions using the VRPayme framework
    ///
    /// - Throws: An error of type 'RequestBuildError'
    func performSync() throws
}
